import axios from 'axios'
import type {
  LoginRequest,
  LoginResponse,
  RegisterRequest,
  RegisterResponse,
  Ticket,
  TicketInfo,
  GetValidationTicketsRequest,
  GetValidationTicketsResponse,
  GetValidationTicketByIdResponse,
  UpdateValidationStatusByTicketIdRequest,
  UpdateValidationStatusByTicketIdResponse,
  CompanyValidationTicket,
  DashboardData,
  Vacancy,
  UpdateVacancyRequest
} from '../types/api'

const API_URL = import.meta.env.VITE_API_URL || 'http://localhost:8080'

const api = axios.create({
  baseURL: API_URL,
  headers: {
    'Content-Type': 'application/json',
  },
})

// Add auth credentials to requests if they exist
api.interceptors.request.use((config) => {
  try {
    const credentials = localStorage.getItem('credentials')
    if (credentials) {
      config.headers.Authorization = `Basic ${credentials}`
    }
  } catch (error) {
    console.error('Error setting auth header:', error)
  }
  return config
}, (error) => {
  return Promise.reject(error)
})

// Add response interceptor for error handling
api.interceptors.response.use(
    (response) => {
      if (response.data && typeof response.data === 'object') {
        return response
      }
      throw new Error('Неверный формат ответа от сервера')
    },
    (error) => {
      if (error.response) {
        // Handle 401 Unauthorized errors
        if (error.response.status === 401) {
          // Clear authentication state
          localStorage.removeItem('credentials')
          localStorage.removeItem('user')
          localStorage.removeItem('isAuthenticated')
          // Redirect to login page if not already there
          if (!window.location.pathname.includes('/login')) {
            window.location.href = '/login'
          }
          return Promise.reject(new Error('Необходима авторизация'))
        }

        // Handle other server errors
        const message = error.response.data?.error || error.response.data || 'Ошибка сервера'
        throw new Error(message)
      } else if (error.request) {
        throw new Error('Нет ответа от сервера. Проверьте подключение.')
      } else {
        throw new Error('Ошибка при выполнении запроса')
      }
    }
)

// Auth endpoints
export const auth = {
  register: (data: RegisterRequest): Promise<{ data: RegisterResponse }> =>
      api.post('/api/v1/register', data),

  login: async (data: LoginRequest): Promise<{ data: LoginResponse }> => {
    try {
      const response = await api.post('/api/v1/login', data)
      return response
    } catch (error) {
      // Clear any stored credentials on error
      localStorage.removeItem('credentials')
      throw error
    }
  },
}

// User validation endpoints
export const userValidation = {
  getValidationTickets: (params?: GetValidationTicketsRequest): Promise<{ data: GetValidationTicketsResponse }> =>
      api.get('/api/v1/users/validations', { params }),

  getValidationTicketById: (id: string): Promise<{ data: GetValidationTicketByIdResponse }> =>
      api.get(`/api/v1/users/validation/${id}`),

  updateValidationStatus: (
      id: string,
      data: UpdateValidationStatusByTicketIdRequest
  ): Promise<{ data: UpdateValidationStatusByTicketIdResponse }> =>
      api.put(`/api/v1/users/validation/${id}`, data),
}

// Company validation endpoints
export const companyValidation = {
  getValidationTickets: (): Promise<{ data: CompanyValidationTicket[] }> =>
      api.get('/api/v1/companies/validations'),

  getValidationTicketById: (id: string): Promise<{ data: CompanyValidationTicket }> =>
      api.get(`/api/v1/companies/validation/${id}`),

  updateValidationStatus: (
      id: string,
      data: UpdateValidationStatusByTicketIdRequest
  ): Promise<{ data: UpdateValidationStatusByTicketIdResponse }> =>
      api.put(`/api/v1/companies/validation/${id}`, data),
}

// Dashboard endpoints
export const dashboard = {
  getDashboardData: (): Promise<{ data: DashboardData }> =>
      api.get('/api/v1/dashboard'),
}

// Vacancy management endpoints
export const vacancies = {
  // Get all vacancies pending moderation
  getPendingVacancies: (): Promise<{ data: Vacancy[] }> =>
      api.get('/api/v1/vacancies/pending'),

  // Get a specific vacancy by ID
  getVacancyById: (id: string): Promise<{ data: Vacancy }> =>
      api.get(`/api/v1/vacancies/${id}`),

  // Update a vacancy (including status changes and agent reward)
  updateVacancy: (id: string, data: UpdateVacancyRequest): Promise<{ data: Vacancy }> =>
      api.put(`/api/v1/vacancies/${id}`, data),

  // Publish a vacancy
  publishVacancy: (id: string): Promise<{ data: Vacancy }> =>
      api.put(`/api/v1/vacancies/${id}/publish`),

  // Reject a vacancy
  rejectVacancy: (id: string, reason: string): Promise<{ data: Vacancy }> =>
      api.put(`/api/v1/vacancies/${id}/reject`, { reason }),
}